import { mdiApi, mdiCashMultiple, mdiHome } from "@mdi/js";
import Icon from "@mdi/react";
import {
  Divider,
  List,
  ListItemButton,
  ListItemIcon,
  ListItemText,
  Typography,
} from "@mui/material";
import React from "react";
import { useLocation } from "react-router-dom";
import { useAccounts } from "../hooks/AccountsListProvider";
import { AccountWidget } from "./AccountWidget";
import { RouterLink } from "./RouterLink";

export function MoneyNavList(): React.ReactElement {
  const accounts = useAccounts();
  return (
    <List
      dense
      component="nav"
      sx={{
        minWidth: "200px",
        backgroundColor: "background.paper",
      }}
    >
      <NavLink
        label="Accueil"
        uri="/"
        icon={<Icon path={mdiHome} size={1} />}
      />

      <NavLink
        label="API Tokens"
        uri="/tokens"
        icon={<Icon path={mdiApi} size={1} />}
      />

      <NavLink
        label="Accounts"
        uri="/accounts"
        icon={<Icon path={mdiCashMultiple} size={1} />}
      />
      <Divider />
      {accounts.list.isEmpty && (
        <Typography
          variant="caption"
          style={{
            paddingTop: "20px",
            display: "inline-block",
            textAlign: "center",
            width: "100%",
          }}
        >
          No account yet.
        </Typography>
      )}

      {accounts.list.list.map((a) => (
        <NavLink
          key={a.id}
          label={a.name}
          uri={`/account/${a.id}`}
          icon={<AccountWidget account={a} />}
        />
      ))}
    </List>
  );
}

function NavLink(p: {
  icon: React.ReactElement;
  uri: string;
  label: string;
}): React.ReactElement {
  const location = useLocation();
  return (
    <RouterLink to={p.uri}>
      <ListItemButton selected={p.uri === location.pathname}>
        <ListItemIcon>{p.icon}</ListItemIcon>
        <ListItemText primary={p.label} />
      </ListItemButton>
    </RouterLink>
  );
}
